==> oculante-0.9.1.tar.gz: oculante-0.9.1/src/icons.rs <==
pub const ARROW_LINE_UP: &str = "\u{E907}";
pub const ARROWS_OUT_SIMPLE: &str = "\u{E904}";
pub const ARROWS_OUT: &str = "\u{E919}";
pub const BOOKMARK: &str = "\u{E910}";
pub const CARET_LEFT: &str = "\u{E902}";
pub const CARET_RIGHT: &str = "\u{E903}";
pub const CHECK: &str = "\u{E91E}";
pub const CHEVRON_DOWN: &str = "\u{E91C}";
pub const CHEVRON_UP: &str = "\u{E91B}";
pub const COPY: &str = "\u{E916}";
pub const DEBUG: &str = "\u{E90D}";
pub const DOWNLOAD: &str = "\u{E912}";
pub const FILE: &str = "\u{E91A}";
pub const FOLDER: &str = "\u{E90A}";
pub const GEAR: &str = "\u{E914}";
pub const GIT_DIFF: &str = "\u{E909}";
pub const HOUSE: &str = "\u{E913}";
pub const IMAGE: &str = "\u{E911}";
pub const INFO: &str = "\u{E905}";
pub const INTERSECT: &str = "\u{E917}";
pub const MOUSE: &str = "\u{E90E}";
pub const LIST: &str = "\u{E90B}";
pub const PALETTE: &str = "\u{E918}";
pub const PENCIL_SIMPLE_LINE: &str = "\u{E906}";
pub const PLACEHOLDER: &str = "\u{E909}";
pub const PLUS: &str = "\u{E91F}";
pub const SEARCH: &str = "\u{E90C}";
pub const SQUARE_ARROW_LEFT: &str = "\u{E900}";
pub const SQUARE_ARROW_RIGHT: &str = "\u{E901}";
pub const CLIPBOARD: &str = "\u{E915}";
pub const SYNC: &str = "\u{E920}";
pub const TRASH: &str = "\u{E908}";
pub const DISPLAY: &str = "\u{E90F}";
pub const X: &str = "\u{E91D}";
pub const LOCATION_PIN: &str = "\u{E921}";
pub const SQUARE_ARROW_UP: &str = "\u{E922}";
pub const SQUARE_ARROW_DOWN: &str = "\u{E923}";
pub const FRAME: &str = "\u{E924}";
pub const MOVE: &str = "\u{E925}";
pub const EXIT: &str = "\u{E926}";
pub const CLOCK: &str = "\u{E927}";
pub const FOLDERIMAGE: &str = "\u{E928}";
pub const FOLDERDOCUMENT: &str = "\u{E929}";
pub const FOLDERDOWNLOAD: &str = "\u{E92a}";
pub const OPTIONS: &str = "\u{E92b}";
pub const BOOKMARK_OFF: &str = "\u{E92c}";
pub const WARNING_CIRCLE: &str = "\u{E92d}";
pub const ERROR_CIRCLE: &str = "\u{E92e}";

// TODO: FIX THESE
// These are used in code, but are not in the list above.
pub const ARROWS_CLOCKWISE: &str = "<>";
pub const RECYCLE: &str = "";
pub const PAINT_BRUSH_HOUSEHOLD: &str = "";
pub const FLOPPY_DISK: &str = "";
pub const ARCHIVE_TRAY: &str = "";
pub const DESKTOP: &str = "🖥";
pub const ARROW_BEND_LEFT_UP: &str = "⬆";
pub const IMAGE_SQUARE: &str = "🖼";
pub const IMAGES: &str = "🖼";
pub const SUN: &str = "🔆";
pub const APERTURE: &str = "";
pub const PAINT_BUCKET: &str = "🌊";
pub const DROP: &str = "💧";
pub const CROP: &str = "⬜";
pub const SWAP: &str = "🔀";
pub const ARROW_CLOCKWISE: &str = "⟳";
pub const SELECTION_INVERSE: &str = "🌓";
pub const FLOW_ARROW: &str = "↕";
pub const CAMERA: &str = "📷";
pub const ARROWS_IN: &str = "↔";
pub const FUNCTION: &str = "🖩";
pub const FILM_STRIP: &str = "🎞";
pub const DOTS_NINE: &str = "🔶";
pub const ARROW_U_UP_LEFT: &str = "⤴";

// pub const HOUSE: &str = "🏠";

==> oculante-0.9.2.tar.gz: oculante-0.9.2/src/icons.rs <==
pub const ARROW_LINE_UP: &str = "\u{E907}";
pub const ARROWS_OUT_SIMPLE: &str = "\u{E904}";
pub const ARROWS_OUT: &str = "\u{E919}";
pub const BOOKMARK: &str = "\u{E910}";
pub const CARET_LEFT: &str = "\u{E902}";
pub const CARET_RIGHT: &str = "\u{E903}";
pub const CHECK: &str = "\u{E91E}";
pub const CHEVRON_DOWN: &str = "\u{E91C}";
pub const CHEVRON_UP: &str = "\u{E91B}";
pub const COPY: &str = "\u{E916}";
pub const DEBUG: &str = "\u{E90D}";
pub const DOWNLOAD: &str = "\u{E912}";
pub const FILE: &str = "\u{E91A}";
pub const FOLDER: &str = "\u{E90A}";
pub const GEAR: &str = "\u{E914}";
pub const GIT_DIFF: &str = "\u{E909}";
pub const HOUSE: &str = "\u{E913}";
pub const IMAGE: &str = "\u{E911}";
pub const INFO: &str = "\u{E905}";
pub const INTERSECT: &str = "\u{E917}";
pub const MOUSE: &str = "\u{E90E}";
pub const LIST: &str = "\u{E90B}";
pub const PALETTE: &str = "\u{E918}";
pub const PENCIL_SIMPLE_LINE: &str = "\u{E906}";
pub const PLACEHOLDER: &str = "\u{E909}";
pub const PLUS: &str = "\u{E91F}";
pub const SEARCH: &str = "\u{E90C}";
pub const SQUARE_ARROW_LEFT: &str = "\u{E900}";
pub const SQUARE_ARROW_RIGHT: &str = "\u{E901}";
pub const CLIPBOARD: &str = "\u{E915}";
pub const SYNC: &str = "\u{E920}";
pub const TRASH: &str = "\u{E908}";
pub const DISPLAY: &str = "\u{E90F}";
pub const X: &str = "\u{E91D}";
pub const LOCATION_PIN: &str = "\u{E921}";
pub const SQUARE_ARROW_UP: &str = "\u{E922}";
pub const SQUARE_ARROW_DOWN: &str = "\u{E923}";
pub const FRAME: &str = "\u{E924}";
pub const MOVE: &str = "\u{E925}";
pub const EXIT: &str = "\u{E926}";
pub const CLOCK: &str = "\u{E927}";
pub const FOLDERIMAGE: &str = "\u{E928}";
pub const FOLDERDOCUMENT: &str = "\u{E929}";
pub const FOLDERDOWNLOAD: &str = "\u{E92a}";
pub const OPTIONS: &str = "\u{E92b}";
pub const BOOKMARK_OFF: &str = "\u{E92c}";
pub const WARNING_CIRCLE: &str = "\u{E92d}";
pub const ERROR_CIRCLE: &str = "\u{E92e}";
pub const FOLDERDESKTOP: &str = "\u{E93b}";
pub const FOLDERBOOKMARK: &str = "\u{E93c}";
pub const BOLDUP: &str = "\u{E92f}";
pub const BOLDDOWN: &str = "\u{E930}";
pub const BOLDX: &str = "\u{E931}";
pub const GHLOGO: &str = "\u{E933}";
pub const CIRCLESQUARE: &str = "\u{E932}";
pub const GRID: &str = "\u{E934}";
pub const BEZEIR: &str = "\u{E935}";
pub const HEART: &str = "\u{E936}";
pub const HEARTFILL: &str = "\u{E937}";
pub const FOLDERFAVOURITES: &str = "\u{E938}";
pub const FOLDERFILL: &str = "\u{E93a}";
pub const TERMINAL: &str = "\u{E939}";
pub const DRIVE: &str = "\u{E93d}";
pub const EYE: &str = "\u{E93e}";
pub const EYEOFF: &str = "\u{E93f}";

// TODO: FIX THESE
// These are used in code, but are not in the list above.
pub const ARROWS_CLOCKWISE: &str = "<>";
pub const RECYCLE: &str = "";
pub const PAINT_BRUSH_HOUSEHOLD: &str = "";
pub const FLOPPY_DISK: &str = "";
pub const ARCHIVE_TRAY: &str = "";
pub const DESKTOP: &str = "🖥";
pub const ARROW_BEND_LEFT_UP: &str = "⬆";
pub const IMAGE_SQUARE: &str = "🖼";
pub const IMAGES: &str = "🖼";
pub const SUN: &str = "🔆";
pub const APERTURE: &str = "";
pub const PAINT_BUCKET: &str = "🌊";
pub const DROP: &str = "💧";
pub const CROP: &str = "⬜";
pub const SWAP: &str = "🔀";
pub const ARROW_CLOCKWISE: &str = "⟳";
pub const SELECTION_INVERSE: &str = "🌓";
pub const FLOW_ARROW: &str = "↕";
pub const CAMERA: &str = "📷";
pub const ARROWS_IN: &str = "↔";
pub const FUNCTION: &str = "🖩";
pub const FILM_STRIP: &str = "🎞";
pub const DOTS_NINE: &str = "🔶";
pub const ARROW_U_UP_LEFT: &str = "⤴";

// pub const HOUSE: &str = "🏠";
